[![Actions Status](https://github.com/pulumi/pulumi-cloudinit/workflows/master/badge.svg)](https://github.com/pulumi/pulumi-cloudinit/actions)
[![Slack](http://www.pulumi.com/images/docs/badges/slack.svg)](https://slack.pulumi.com)
[![NPM version](https://badge.fury.io/js/%40pulumi%2Fcloudinit.svg)](https://npmjs.com/package/@pulumi/cloudinit)
[![NuGet version](https://badge.fury.io/nu/pulumi.cloudinit.svg)](https://badge.fury.io/nu/pulumi.cloudinit)
[![Python version](https://badge.fury.io/py/pulumi-cloudinit.svg)](https://pypi.org/project/pulumi-cloudinit)
[![PkgGoDev](https://pkg.go.dev/badge/github.com/pulumi/pulumi-cloudinit/sdk/go)](https://pkg.go.dev/github.com/pulumi/pulumi-cloudinit/sdk/go)
[![License](https://img.shields.io/npm/l/%40pulumi%2Fpulumi.svg)](https://github.com/pulumi/pulumi-cloudinit/blob/master/LICENSE)

# CloudInit Provider

Provider for rendering [cloud-init](https://cloudinit.readthedocs.io/) configurations.

## Installing

This package is available in many languages in the standard packaging formats.

### Node.js (Java/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either `npm`:

    $ npm install @pulumi/cloudinit

or `yarn`:

    $ yarn add @pulumi/cloudinit

### Python 3

To use from Python, install using `pip`:

    $ pip install pulumi_cloudinit

### Go

To use from Go, use `go get` to grab the latest version of the library

    $ go get github.com/pulumi/pulumi-cloudinit/sdk

### .NET

To use from .NET, install using `dotnet add package`:

    $ dotnet add package Pulumi.CloudInit

## Reference

For further information, please visit [the CloudInit provider docs](https://www.pulumi.com/docs/intro/cloud-providers/cloudinit) or for detailed reference documentation, please visit [the API docs](https://www.pulumi.com/docs/reference/pkg/cloudinit).
